pub trait WalletFederationApi {
// Required methods
fn module_consensus_version<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<ModuleConsensusVersion>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_consensus_block_count<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u64>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_peg_out_fees<'life0, 'life1, 'async_trait>(
&'life0 self,
address: &'life1 Address,
amount: Amount,
) -> Pin<Box<dyn Future<Output = FederationResult<Option<PegOutFees>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn fetch_bitcoin_rpc_kind<'life0, 'async_trait>(
&'life0 self,
peer_id: PeerId,
) -> Pin<Box<dyn Future<Output = FederationResult<String>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_bitcoin_rpc_config<'life0, 'async_trait>(
&'life0 self,
auth: ApiAuth,
) -> Pin<Box<dyn Future<Output = FederationResult<BitcoinRpcConfig>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_wallet_summary<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<WalletSummary>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_block_count_local<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u32>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn is_utxo_confirmed<'life0, 'async_trait>(
&'life0 self,
outpoint: OutPoint,
) -> Pin<Box<dyn Future<Output = FederationResult<bool>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn activate_consensus_version_voting<'life0, 'async_trait>(
&'life0 self,
auth: ApiAuth,
) -> Pin<Box<dyn Future<Output = FederationResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_recovery_count<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u64>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn fetch_recovery_slice<'life0, 'async_trait>(
&'life0 self,
start: u64,
end: u64,
) -> Pin<Box<dyn Future<Output = Vec<RecoveryItem>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
fn module_consensus_version<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<ModuleConsensusVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_consensus_block_count<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u64>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_peg_out_fees<'life0, 'life1, 'async_trait>(
&'life0 self,
address: &'life1 Address,
amount: Amount,
) -> Pin<Box<dyn Future<Output = FederationResult<Option<PegOutFees>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn fetch_bitcoin_rpc_kind<'life0, 'async_trait>(
&'life0 self,
peer_id: PeerId,
) -> Pin<Box<dyn Future<Output = FederationResult<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_bitcoin_rpc_config<'life0, 'async_trait>(
&'life0 self,
auth: ApiAuth,
) -> Pin<Box<dyn Future<Output = FederationResult<BitcoinRpcConfig>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_wallet_summary<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<WalletSummary>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_block_count_local<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u32>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn is_utxo_confirmed<'life0, 'async_trait>(
&'life0 self,
outpoint: OutPoint,
) -> Pin<Box<dyn Future<Output = FederationResult<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn activate_consensus_version_voting<'life0, 'async_trait>(
&'life0 self,
auth: ApiAuth,
) -> Pin<Box<dyn Future<Output = FederationResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn fetch_recovery_count<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u64>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_recovery_count<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = FederationResult<u64>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns the total number of recovery items stored on the federation
Sourcefn fetch_recovery_slice<'life0, 'async_trait>(
&'life0 self,
start: u64,
end: u64,
) -> Pin<Box<dyn Future<Output = Vec<RecoveryItem>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_recovery_slice<'life0, 'async_trait>(
&'life0 self,
start: u64,
end: u64,
) -> Pin<Box<dyn Future<Output = Vec<RecoveryItem>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Fetches recovery items in the range [start, end) via consensus.
Retries each peer with backoff until a threshold of peers agree, so a transient transport failure on one peer (on top of a peer that is already offline) does not abort the whole recovery.